# Fact Sheet Permissions
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions#overview)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions#best-practices)
  * [Configuring Fact Sheet Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions#configuring-fact-sheet-permissions)
  * [Permissions Overview](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions#permissions-overview)
  * [General Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions#general-permissions)
  * [Global Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions#global-permissions)
  * [Permissions for Subscription Types](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions#permissions-for-subscription-types)
  * [Field Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions#field-permissions)


View all
Configure fact sheet permissions for non-admin user roles.
